# 远行星号译文格式规范

得益于灰色渡鸦和绅士猫对游戏排版系统的修正，译文不再需要使用花括号替代空格，
长句子也不再需要插入空格来进行分割，敬请留意。

> 请注意，内核 jar 文件的翻译规则与其他部分有所不同，请参考最后的[内核 .jar 文件汉化规则怪谈](#内核-jar-文件汉化规则怪谈)。

> 请注意，为了使显示效果更清晰，以下所有原文、译文示例中的空格用`·`表示。

## 标点符号

- `，。！？：；`使用中文标点
- 圆括号使用英文`()`，并在括号外前后空格
- 方括号使用`[]`，并在括号外前后空格
- 单引号(`‘’`)和双引号(`“”`)改为直引号(`'`和`"`)，并在前后引号外加空格
- 省略号或表示停顿使用三个英文句号(`...`)
- 中文破折号使用`——`，并在前后添加空格
- 连字符使用`-`，不加空格
  - 不要作为破折号使用
  - 例：`典范-级`
- 数字之中用于分割位数的`,`使用英文标点
  - 例：`8,000·星币`

## 空格

- **中文、英文、数值**之间空格
  - 例：`报告都会实时更新到你的·TriPad·上`
  - 例：`海军勒令·224·项·34·条之规定`
- **token 前后空格**
  - 例：`你最近在·$market·附近采取的行动`
- 人称代词前后不空格
  - `$heOrShe`、`$hisOrHer`、`$himOrHer`、`$himOrHerself`、`$manOrWoman` 前后不空格
  - `$**_manOrWoman`、`$**_heOrShe` 等这种代表人称代词的也不空格
- `$shipOrFleet`, `$**shipOrFleet` 前后不空格
- **人名，地名，专有名词**或需要强调的词组前后空格
    - 例：`舰长·Peter·在一次战斗中取得了胜利。`
    - 例：`前往·Galatia·学院接受任务。`
    - 例：`使用·"双面神"·装置`
    - 但如果在标点符号前，则后面不空格。
        - 例：`目标是 Jangala·！` 改为 `目标是 Jangala！`
- 连续的标点中间不空格
    - 例：` "啊，是您！·" ` 改为 ` "啊，是您！" `
    - 例：`卢德难道不是为此而死的吗？·！·` 改为 `卢德难道不是为此而死的吗？！ `
- **不能连续空格** *（不适用于内核jar文件）*
- 段首不空格 *（不适用于内核jar文件）*
    - 例：(段首)`·Gargoyle 目瞪口呆地看着你` 改为 (段首)`Gargoyle 目瞪口呆地看着你`

## Token

- token指以`$`开头的特殊词语，其内容在游戏运行过程中由系统动态替换。
- `$heOrShe`将会被系统替换成`他`或者`她`。
- `$hisOrHer`、`$himOrHer`、`$himOrHerself`**也会被系统替换成`他`或者`她`**。
    - 如果需要翻译成`他(她)的`，请写成`$hisOrHer的`。
    - 如果需要翻译成`他(她)自己`，请写成`$himOrHerself自己`。

## ParaTranz 平台规则

- 由于平台机制原因，我们规定所有的`\n`必须使用`^n`进行替代。
    - 例：`AddText·"\"很好。感谢你的努力。\""\nCallEvent` 
    - 改为
      `AddText·"\"很好。感谢你的努力。\""^nCallEvent`。
- 请注意这个`\n`**不是换行**，是文本中直接出现的两个字符。换行无需特殊处理。
- 该情况目前只出现在`rules.csv`的`script`列中。

## 内核 .jar 文件汉化规则怪谈

内核文件指的是游戏源文件中以 jar 格式存在的文件。这些文件包含了游戏的 java 代码，一些需要翻译的内容被以字符串形式硬编码在了其中。

由于这些文件的特殊性，在翻译时务必注意以下几点：

- **词条中的`%`必须保留，不可删除。** 这是标记插入数字或者单一高亮单词的占位符。
  - **前后必须有空格**
  - 例：`Abandoning·%s,·a·size·%s·colony` 译为 `遗弃·%s·这处·%s·规模的殖民地`
- **词条开头结尾的空格个数必须与原文保持一致。** 部分游戏代码依赖于这些空格。
  - 例：`Phase·` 译为 `相位·`
- 如果翻译时看到语句支离破碎，那很可能是因为上下文被其他自动替换的地名，人名，数字所隔断。必须结合上下文整体翻译
  - 请参考：[按源文件顺序显示词条](tut_translator.md#重要按源文件顺序显示词条)
- 如果翻译到句尾发现少个句号，那多半在下一个词条。无需手动添加。
- 不需要强求每个翻译词条都有字，中文表达中不需要的词可以将译文留空
  - 例如部分英文特有的语言结构，如单复数，a和an，根据情况可以留空
- 如果遇到格式不确定的情况，请将词条标为`有疑问`并咨询灰色渡鸦或jn_xyp
